@@ -1,17 +1,36 @@
 package Software::Catalog::Role::Software;
 
-our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
-our $DATE = '2020-10-02'; # DATE
-our $DIST = 'Software-Catalog'; # DIST
-our $VERSION = '1.0.7'; # VERSION
-
 use Role::Tiny;
 
 use PerlX::Maybe;
 
-sub available_archs {
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2024-07-17'; # DATE
+our $DIST = 'Software-Catalog'; # DIST
+our $VERSION = '1.0.8'; # VERSION
+
+sub available_platform_labels {
     my $self = shift;
-    sort keys %{ $self->canon2native_arch_map };
+    sort keys %{ $self->platform_labels_to_specs };
+}
+
+sub first_matching_platform_label {
+    require Devel::Platform::Info;
+    require Devel::Platform::Match;
+
+    my ($self, $platform_info) = @_;
+    if (!defined($platform_info)) {
+        $platform_info = Devel::Platform::Info->new->get_info;
+    }
+
+    my $platform_labels_to_specs = $self->platform_labels_to_specs;
+    for my $platform_label (keys %$platform_labels_to_specs) {
+        my $platform_spec = $platform_labels_to_specs->{$platform_label};
+        if (Devel::Platform::Match::match_platform_bool($platform_spec, $platform_info)) {
+            return $platform_label;
+        }
+    }
+    undef;
 }
 
 requires 'archive_info';
@@ -20,14 +39,15 @@ around archive_info => sub {
     my $orig = shift;
     my ($self, %args) = @_;
 
-    # supply default for 'arch' argument
-    if (!defined $args{arch}) {
-        $args{arch} = $self->_detect_arch;
+    # supply default for 'platform_label' argument
+    if (!defined $args{platform_label}) {
+        $args{platform_label} = $self->first_matching_platform_label or
+        return [412, "Platform not supported"];
     }
 
     # supply default for 'version' argument
     if (!defined $args{version}) {
-        my $verres = $self->latest_version(maybe arch => $args{arch});
+        my $verres = $self->latest_version(maybe platform_label => $args{platform_label});
         return [500, "Can't get latest version: $verres->[0] - $verres->[1]"]
             unless $verres->[0] == 200;
         $args{version} = $verres->[2];
@@ -44,17 +64,15 @@ around available_versions => sub {
     my $orig = shift;
     my ($self, %args) = @_;
 
-    # supply default for 'arch' argument
-    if (!defined $args{arch}) {
-        require Software::Catalog::Util;
-        $args{arch} = Software::Catalog::Util::detect_arch();
+    # supply default for 'platform_label' argument
+    if (!defined $args{platform_label}) {
+        $args{platform_label} = $self->first_matching_platform_label or
+        return [412, "Platform not supported"];
     }
 
     $orig->($self, %args);
 };
 
-requires 'canon2native_arch_map';
-
 requires 'cmp_version'; # usually from versioning scheme role
 
 requires 'homepage_url';
@@ -69,28 +87,32 @@ around latest_version => sub {
     my $orig = shift;
     my ($self, %args) = @_;
 
-    # supply default for 'arch' argument
-    if (!defined $args{arch}) {
-        $args{arch} = $self->_detect_arch;
+    # supply default for 'platform_label' argument
+    if (!defined $args{platform_label}) {
+        $args{platform_label} = $self->first_matching_platform_label or
+        return [412, "Platform not supported"];
     }
 
     $orig->($self, %args);
 };
 
+requires 'platform_labels_to_specs';
+
 requires 'download_url';
 
 around download_url => sub {
     my $orig = shift;
     my ($self, %args) = @_;
 
-    # supply default for 'arch' argument
-    if (!defined $args{arch}) {
-        $args{arch} = $self->_detect_arch;
+    # supply default for 'platform_label' argument
+    if (!defined $args{platform_label}) {
+        $args{platform_label} = $self->first_matching_platform_label or
+        return [412, "Platform not supported"];
     }
 
     # supply default for 'version' argument
     if (!defined $args{version}) {
-        my $verres = $self->latest_version(maybe arch => $args{arch});
+        my $verres = $self->latest_version(maybe platform_label => $args{platform_label});
         return [500, "Can't get latest version: $verres->[0] - $verres->[1]"]
             unless $verres->[0] == 200;
         $args{version} = $verres->[2];
@@ -107,14 +129,15 @@ around release_note => sub {
     my $orig = shift;
     my ($self, %args) = @_;
 
-    # supply default for 'arch' argument
-    if (!defined $args{arch}) {
-        $args{arch} = $self->_detect_arch;
+    # supply default for 'platform_label' argument
+    if (!defined $args{platform_label}) {
+        $args{platform_label} = $self->first_matching_platform_label or
+        return [412, "Platform not supported"];
     }
 
     # supply default for 'version' argument
     if (!defined $args{version}) {
-        my $verres = $self->latest_version(maybe arch => $args{arch});
+        my $verres = $self->latest_version(maybe platform_label => $args{platform_label});
         return [500, "Can't get latest version: $verres->[0] - $verres->[1]"]
             unless $verres->[0] == 200;
         $args{version} = $verres->[2];
@@ -125,34 +148,6 @@ around release_note => sub {
     $orig->($self, %args);
 };
 
-sub _canon2native_arch {
-    my ($self, $arch) = @_;
-
-    my $map = $self->canon2native_arch_map;
-    my $rmap = {reverse %$map};
-    if ($map->{$arch}) {
-        return $map->{$arch};
-    } elsif ($rmap->{$arch}) {
-        return $arch;
-    } else {
-        die "Unknown arch '$arch'";
-    }
-}
-
-sub _native2canon_arch {
-    my ($self, $arch) = @_;
-
-    my $map = $self->canon2native_arch_map;
-    my $rmap = {reverse %$map};
-    if ($rmap->{$arch}) {
-        return $rmap->{$arch};
-    } elsif ($map->{$arch}) {
-        return $arch;
-    } else {
-        die "Unknown arch '$arch'";
-    }
-}
-
 1;
 # ABSTRACT: Role for software
 
@@ -168,7 +163,9 @@ Software::Catalog::Role::Software - Role for software
 
 =head1 VERSION
 
-This document describes version 1.0.7 of Software::Catalog::Role::Software (from Perl distribution Software-Catalog), released on 2020-10-02.
+This document describes version 1.0.8 of Software::Catalog::Role::Software (from Perl distribution Software-Catalog), released on 2024-07-17.
+
+=for Pod::Coverage ^(.+)$
 
 =head1 REQUIRED METHODS
 
@@ -194,11 +191,9 @@ Arguments:
 
 =over
 
-=item * arch
+=item * platform_label
 
-Str, must be one of known architectures (see L</canon2native_arch_map>).
-Optional. If not specified, this role's method modifier will supply
-the default (the architecture the perl interpreter is built on).
+Str, ...
 
 =item * format
 
@@ -228,11 +223,9 @@ Arguments:
 
 =over
 
-=item * arch
+=item * platform_label
 
-Str, must be one of known architectures (see L</canon2native_arch_map>).
-Optional. If not specified, this role's method modifier will supply
-the default (the architecture the perl interpreter is built on).
+Str, ...
 
 =back
 
@@ -240,32 +233,6 @@ If you do not want to provide this functionality, you can return something like:
 
  [501, "Not implemented"]
 
-=head2 canon2native_arch_map
-
-Return a mapping of architecture names from canonical to native.
-
- my $hashref = $swobj->canon2native_arch_map;
-
-The canonical architecture names are:
-
- linux-x86        (Linux, Intel x86 32bit)
- linux-x86_64     (Linux, AMD/Intel 64bit)
- win32            (Windows, Intel x86 32bit)
- win64            (Windows, AMD/Intel 64bit)
-
-Since each software might label the architectures differently, you will need to
-provide a mapping. For example:
-
- sub canon2native_arch_map {
-     return +{
-         'linux-x86_64' => 'linux64',
-         'win64' => 'win64',
-     },
- }
-
-When an architecture is not mapped, it is assumed to be unsupported by the
-software.
-
 =head2 cmp_version
 
 Compare two version strings and return -1|0|1 like Perl's C<cmp()> operator.
@@ -293,11 +260,9 @@ Arguments:
 
 =over
 
-=item * arch
+=item * platform_label
 
-Str, must be one of known architectures (see L</canon2native_arch_map>).
-Optional. If not specified, this role's method modifier will supply
-the default (the architecture the perl interpreter is built on).
+Str, ....
 
 =item * version
 
@@ -358,11 +323,9 @@ Arguments:
 
 =over
 
-=item * arch
+=item * platform_label
 
-Str, must be one of known architectures (see L</canon2native_arch_map>).
-Optional. If not specified, this role's method modifier will supply
-the default (the architecture the perl interpreter is built on).
+Str, ....
 
 =item * version
 
@@ -371,6 +334,11 @@ the default from L</latest_version>.
 
 =back
 
+=head2 platform_label_to_spec
+
+List supporter platforms. Must return a hashref of platform labels as key and
+platform specifications as values (see L<Devel::Platform::Match>).
+
 =head2 release_note
 
 Get release note.
@@ -387,11 +355,9 @@ Arguments:
 
 =over
 
-=item * arch
+=item * platform_label
 
-Str, must be one of known architectures (see L</canon2native_arch_map>).
-Optional. If not specified, this role's method modifier will supply
-the default (the architecture the perl interpreter is built on).
+Str, ...
 
 =item * format
 
@@ -407,13 +373,13 @@ the default from L</latest_version>.
 
 =head1 PROVIDED METHODS
 
-=head2 available_archs
+=head2 available_platform_labels
 
-Return a sorted list of available architectures for a software.
+Return a sorted list of available platforms for a software.
 
- my @archs = $swobj->available_archs;
+ my @platform_labels = $swobj->available_platform_labels;
 
-This information is retrieved from L</canon2native_arch_map>.
+This information is retrieved from L</platform_label_to_spec>.
 
 =head1 HOMEPAGE
 
@@ -423,6 +389,35 @@ Please visit the project's homepage at L<https://metacpan.org/release/Software-C
 
 Source repository is at L<https://github.com/perlancar/perl-Software-Catalog>.
 
+=head1 AUTHOR
+
+perlancar <perlancar@cpan.org>
+
+=head1 CONTRIBUTING
+
+
+To contribute, you can send patches by email/via RT, or send pull requests on
+GitHub.
+
+Most of the time, you don't need to build the distribution yourself. You can
+simply modify the code, then test via:
+
+ % prove -l
+
+If you want to build the distribution (e.g. to try to install it locally on your
+system), you can install L<Dist::Zilla>,
+L<Dist::Zilla::PluginBundle::Author::PERLANCAR>,
+L<Pod::Weaver::PluginBundle::Author::PERLANCAR>, and sometimes one or two other
+Dist::Zilla- and/or Pod::Weaver plugins. Any additional steps required beyond
+that are considered a bug and can be reported to me.
+
+=head1 COPYRIGHT AND LICENSE
+
+This software is copyright (c) 2024, 2020, 2019, 2018, 2015, 2014, 2012 by perlancar <perlancar@cpan.org>.
+
+This is free software; you can redistribute it and/or modify it under
+the same terms as the Perl 5 programming language system itself.
+
 =head1 BUGS
 
 Please report any bugs or feature requests on the bugtracker website L<https://rt.cpan.org/Public/Dist/Display.html?Name=Software-Catalog>
@@ -431,15 +426,4 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
-=head1 AUTHOR
-
-perlancar <perlancar@cpan.org>
-
-=head1 COPYRIGHT AND LICENSE
-
-This software is copyright (c) 2020, 2019, 2018, 2015, 2014, 2012 by perlancar@cpan.org.
-
-This is free software; you can redistribute it and/or modify it under
-the same terms as the Perl 5 programming language system itself.
-
 =cut
